{% load i18n %}
<section class="quiz-plugin">
  <{{ instance.title_level }} class="quiz-title">
  {{ instance.quiz.name }}
</{{ instance.title_level }}>
{% if instance.short_description %}
  <p class="quiz-description">
    {{ instance.short_description }}
  </p>
{% endif %}
<a class="quiz-launch-button" href="{% url 'interpretation_quiz' instance.quiz.id %}">{% if instance.button_text %}{{ instance.button_text }}{% else %}{% trans "Launch the quiz" %}{% endif %}</a>
</section>
