# Generated by Django 4.2.13 on 2024-06-04 15:16

# Django
import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("django_easy_quiz", "0004_auto_20231009_1707"),
    ]

    operations = [
        migrations.AddField(
            model_name="savedquiz",
            name="interpretation_max_symbol",
            field=models.CharField(blank=True, max_length=32, null=True),
        ),
        migrations.AlterField(
            model_name="interpretationplugin",
            name="cmsplugin_ptr",
            field=models.OneToOneField(
                auto_created=True,
                on_delete=django.db.models.deletion.CASCADE,
                parent_link=True,
                primary_key=True,
                related_name="%(app_label)s_%(class)s",
                serialize=False,
                to="cms.cmsplugin",
            ),
        ),
        migrations.AlterField(
            model_name="interpretationplugin",
            name="title_level",
            field=models.CharField(
                choices=[
                    ("h1", "Titre niveau 1 (<h1>)"),
                    ("h2", "Titre niveau 2 (<h2>)"),
                    ("h3", "Titre niveau 3 (<h3>)"),
                    ("h4", "Titre niveau 4 (<h4>)"),
                    ("h5", "Titre niveau 5 (<h5>)"),
                    ("h6", "Titre niveau 6 (<h6>)"),
                ],
                help_text="Niveau du titre",
                max_length=4,
            ),
        ),
        migrations.AlterField(
            model_name="moreinfoquestion",
            name="answer_is_list",
            field=models.BooleanField(
                default=False,
                help_text="Cochez cette case pour lister les réponses dans un élément 'select', plus compact que des boutons type 'radio'.",
            ),
        ),
        migrations.AlterField(
            model_name="weightedanswersplugin",
            name="cmsplugin_ptr",
            field=models.OneToOneField(
                auto_created=True,
                on_delete=django.db.models.deletion.CASCADE,
                parent_link=True,
                primary_key=True,
                related_name="%(app_label)s_%(class)s",
                serialize=False,
                to="cms.cmsplugin",
            ),
        ),
        migrations.AlterField(
            model_name="weightedanswersplugin",
            name="title_level",
            field=models.CharField(
                choices=[
                    ("h1", "Titre niveau 1 (<h1>)"),
                    ("h2", "Titre niveau 2 (<h2>)"),
                    ("h3", "Titre niveau 3 (<h3>)"),
                    ("h4", "Titre niveau 4 (<h4>)"),
                    ("h5", "Titre niveau 5 (<h5>)"),
                    ("h6", "Titre niveau 6 (<h6>)"),
                ],
                help_text="Niveau du titre",
                max_length=4,
            ),
        ),
    ]
