# Generated by Django 3.2.24 on 2024-06-12 11:51

# Django
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("django_easy_quiz", "0005_savedquiz_interpretation_max_symbol_and_more"),
    ]

    operations = [
        migrations.AddField(
            model_name="weightedanswersquiz",
            name="show_score_summary",
            field=models.BooleanField(
                default=True, verbose_name="Show score in summary"
            ),
        ),
    ]
